# Define the kmod package name here.
%define kmod_name fmc-tdc
%define kmods_built fmc-tdc.ko

%define tagversion 2015-05
%define packageversion %(echo %{tagversion} | sed 's/-/./g')

%define gitversion 0-g461182b

%define sourceversion %(echo %{gitversion} | sed 's/-/./g')

%define fmc_ver 0.1
%define zio_ver 0.1
%define spec_sw_ver 0.0

# If kversion isn't defined on the rpmbuild line, define it here.
%{!?kversion: %define kversion 3.10.0-693.el7.%{_target_cpu}}

Name:    %{kmod_name}-kmod
Version: 0.0
Release: %{packageversion}.%{sourceversion}.2%{?dist}
Group:   System Environment/Kernel
License: GPLv2
Summary: %{kmod_name} kernel module(s)
URL:     https://www.ohwr.org/projects/fmc-tdc-sw/repository

BuildRequires: perl
BuildRequires: redhat-rpm-config
ExclusiveArch: x86_64

BuildRequires: git
BuildRequires: fmc-kmod-tools   = %{fmc_ver}
BuildRequires: fmc-kmod-headers = %{fmc_ver}
BuildRequires: zio-kmod-headers = %{zio_ver}
BuildRequires: spec-sw-kmod-headers = %{spec_sw_ver}

# for docs
BuildRequires: emacs texinfo-tex doxygen

# Sources.
Source0:  %{kmod_name}-%{version}.tar.bz2
Source5:  GPL-v2.0.txt
Source10: kmodtool-%{kmod_name}-el7.sh

Patch1: fmc-tdc-makefile.patch

# Magic hidden here.
%{expand:%(sh %{SOURCE10} rpmtemplate %{kmod_name} %{kversion} "")}

# Disable the building of the debug package(s).
%define debug_package %{nil}

%description
This package provides the %{kmod_name} kernel module(s).
It is built to depend upon the specific ABI provided by a range of releases
of the same variant of the Linux kernel and not on any one specific build.

%package headers
Summary: Kernel headers for %{kmod_name}
Requires:       %{kmod_name}-kmod = %{version}

%description headers
Kernel headers for %{kmod_name}-kmod

%package tools
Summary: Userspace utilities for %{kmod_name}
Requires:	%{kmod_name}-kmod = %{version}

%description tools
Tools for %{kmod_name}-kmod

%prep
%setup -q -n %{kmod_name}-%{version}
for thiskmod in %{kmods_built}; do
    echo "override ${thiskmod} * weak-updates/%{kmod_name}" > kmod-%{kmod_name}.conf
done

GIT_VERSION=$(git describe --dirty --long --tags)

cat << EOF > fmc-tdc-version-env
GIT_VERSION=${GIT_VERSION}
FMC_TDC_VERSION=${GIT_VERSION}
FINE_TDC_SW_VERSION=${GIT_VERSION}
EOF

%patch1 -p1



%build
KSRC=%{_usrsrc}/kernels/%{kversion}
FMC_HEADERS='/usr/src/kmods/fmc-%{fmc_ver}'
ZIO_HEADERS='/usr/src/kmods/zio-%{zio_ver}'
SPEC_HEADERS='/usr/src/kmods/spec-sw-%{spec_sw_ver}'

%{__cat} ${FMC_HEADERS}/Module.symvers ${ZIO_HEADERS}/Module.symvers ${SPEC_HEADERS}/Module.symvers > kernel/Module.symvers

source ${FMC_HEADERS}/fmc-version-env
source ${ZIO_HEADERS}/zio-version-env
source ${SPEC_HEADERS}/spec-sw-version-env

pushd kernel
%{__cp} ${FMC_HEADERS}/access.o .
%{__cp} ${FMC_HEADERS}/glue.o .
%{__make} LINUX="${KSRC}" FMC_BUS=${FMC_HEADERS} FMC_BUS_VERSION=${FMC_BUS_VERSION} ZIO=${ZIO_HEADERS} ZIO_VERSION=${ZIO_VERSION} SPEC_SW=${SPEC_HEADERS} SPEC_SW_VERSION=${SPEC_SW_VERSION}
popd

# Cleanup the mappings
for line in $(cat kernel/modules.order); do
  kmod=$(basename ${line})
  echo "kernel/extra/${kmod}" >> kernel/fmc-fine.order
done

awk '{print $1 "\t" $2 "\textra/fmc\t" $4}' kernel/Module.symvers > kernel/fmc-fine.symvers


# Build application tools
pushd lib
%{__make} ZIO=${ZIO_HEADERS} ZIO_GIT_VERSION=${ZIO_VERSION}
popd

pushd tools
%{__make} %{?_smp_mflags}
popd

# Build docs
pushd doc
%{__make} %{?_smp_mflags}
popd



%install
# Setup headers
%{__install} -d %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/linux
echo "%{tagversion}-%{gitversion}" > %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/version
%{__install} fmc-tdc-version-env %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/fmc-tdc-version-env

%{__install} kernel/fmc-fine.order %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/modules.order
%{__install} kernel/fmc-fine.symvers %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/Module.symvers
for filename in $(cd kernel ; find . -type f -name \*.h); do
    %{__install} -D kernel/${filename} %{buildroot}%{_usrsrc}/kmods/%{kmod_name}-%{version}/linux/${filename}
done

# install tools
%{__install} -d %{buildroot}%{_libdir}
%{__install} lib/libfmctdc.a %{buildroot}%{_libdir}
%{__install} -d %{buildroot}%{_sbindir}
%{__install} tools/fmc-tdc-list %{buildroot}%{_sbindir}/
%{__install} tools/fmc-tdc-temperature %{buildroot}%{_sbindir}/
%{__install} tools/fmc-tdc-term %{buildroot}%{_sbindir}/
%{__install} tools/fmc-tdc-time %{buildroot}%{_sbindir}/
%{__install} tools/fmc-tdc-tstamp %{buildroot}%{_sbindir}/

%{__install} -d %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
for thiskmod in %{kmods_built}; do
    %{__install} kernel/${thiskmod} %{buildroot}/lib/modules/%{kversion}/extra/%{kmod_name}/
done
%{__install} -d %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} kmod-%{kmod_name}.conf %{buildroot}%{_sysconfdir}/depmod.d/
%{__install} -d %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/
%{__install} %{SOURCE5} %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/

%{__install} kernel/fmc-fine.order %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/modules.order
%{__install} kernel/fmc-fine.symvers %{buildroot}%{_defaultdocdir}/kmod-%{kmod_name}-%{version}/Module.symvers


# strip the modules(s)
find %{buildroot} -type f -name \*.ko -exec %{__strip} --strip-debug \{\} \;

# Sign the modules(s)
%if %{?_with_modsign:1}%{!?_with_modsign:0}
# If the module signing keys are not defined, define them here.
%{!?privkey: %define privkey %{_sysconfdir}/pki/SECURE-BOOT-KEY.priv}
%{!?pubkey: %define pubkey %{_sysconfdir}/pki/SECURE-BOOT-KEY.der}
for module in $(find %{buildroot} -type f -name \*.ko);
do %{__perl} /usr/src/kernels/%{kversion}/scripts/sign-file \
sha256 %{privkey} %{pubkey} $module;
done
%endif

%clean
%{__rm} -rf %{buildroot}

%files tools
%defattr(0644,root,root,0755)
%docdir %{_defaultdocdir}/fmc-tdc-%{version}
# management tools either make use of dev nodes with
#  group dialout, or outright calls to the kernel
%attr(4750, root, dialout) %{_sbindir}/*
%{_libdir}/*

%files headers
%defattr(0644,root,root,0755)
%{_usrsrc}/kmods/%{kmod_name}-%{version}


%changelog
* Fri Sep 01 2017 Akemi Yagi<toracat@elrepo.org> - 0.0-2015.05.0.g461182b.2
- bug fix [elrepo bug #688 comment 5455]

* Tue Aug 29 2017 Akemi Yagi<toracat@elrepo.org> - 0.0-2015.05.0.g461182b.1
- Initial el7 build of the kmod package
- Submitted by jcpunk [elrepo bug #688]
